diff --git a/scipost/templates/scipost/EdCol_by-laws.html b/scipost/templates/scipost/EdCol_by-laws.html
index 08e014d550ae3b266a4a8724881951776ae6ffce..f5198bca0164a65fcfbb3b6b60c878f32429403f 100644
--- a/scipost/templates/scipost/EdCol_by-laws.html
+++ b/scipost/templates/scipost/EdCol_by-laws.html
@@ -148,14 +148,14 @@
 	  for all SciPost Journals. The College shall strive for the very highest standards of
 	  professionalism achievable in the refereeing process.</p>
 	<ol>
-	  <li>Submissions queue
+	  <li>Submissions pool
 	    <p>
-	      Incoming Submissions are added to the queue of manuscripts under consideration for publication.
-	      This queue is visible to all members of the Editorial College, as well as to the Advisory Board and Foundation.
-	      Each item in the queue represents a single Submission's whole history, including
+	      Incoming Submissions are added to the pool of manuscripts under consideration for publication.
+	      This pool is visible to all members of the Editorial College, as well as to the Advisory Board and Foundation.
+	      Each item in the pool represents a single Submission's whole history, including
 	      possible earlier (pre-resubmission) versions.</p>
 	    <p>
-	      Submissions in the queue can be in any of the following stages:
+	      Submissions in the pool can be in any of the following stages:
 	      <ul>
 		<li>Pre-screening</li>
 		<li>Editor-in-charge appointed</li>
@@ -172,12 +172,14 @@
 	  </li>
 	  <li>Pre-screening
 	    <p>
-	      For each queued Submission, five Fellows are sent an assignment request.
+	      For each Submission added to the pool, five Fellows are sent an assignment request
+	      to become Editor-in-charge.
 	      The recipients of these requests are selected by matching the submission's specialty 
 	      specifiers to the stated specialties of the Fellows, priority being given to Fellows 
 	      marked as currently available.
 	      Other Fellows within the Editorial College do not receive an assignment request but
-	      can still view a Submission's details through their visibility rights on the Submissions queue.
+	      can still view a Submission's details and volunteer to become Editor-in-charge
+	      through their visibility rights on the Submissions pool.
 	    </p>
 	    <p>
 	      Each assigned Fellow can explicitly decline the assignment, stating a reason among:
@@ -197,7 +199,7 @@
 	  </li>
 	  <li>Appointment of Editor-in-charge
 	    <p>The first Fellow of the Editorial College who accepts an assignment, 
-	      or who volunteers while perusing the queue, becomes Editor-in-charge of the Submission, 
+	      or who volunteers while perusing the pool, becomes Editor-in-charge of the Submission, 
 	      under the conditions that:
 	      <ol>
 		<li>the Submission's main specialty matches one of the Fellow's stated specialties</li>
diff --git a/submissions/models.py b/submissions/models.py
index 549d98bc4490f6edbd02255dd6db94e36c8fb992..4b4c43e3d2d78f2cdc948670c2cb3faff3df01a4 100644
--- a/submissions/models.py
+++ b/submissions/models.py
@@ -19,7 +19,7 @@ from journals.models import journals_submit_dict, journals_domains_dict, journal
 
 SUBMISSION_STATUS = (
     ('unassigned', 'Unassigned'),
-    ('assigned', 'Assigned to a specialty editor (response pending)'),
+#    ('EICrequested', 'A request to become EIC has been sent to a specialty editor (response pending)'),
     ('assignment_failed', 'Failed to assign Editor-in-charge; manuscript rejected'),
     ('EICassigned', 'Editor-in-charge assigned, manuscript under review'),
     ('review_closed', 'Review period closed, editorial recommendation pending'),
@@ -32,7 +32,7 @@ submission_status_dict = dict(SUBMISSION_STATUS)
 
 SUBMISSION_ACTION_REQUIRED = (
     ('assign_EIC', 'Editor-in-charge to be assigned'),
-    ('Fellow_accepts_or_refuse_assignment', 'Fellow must accept or refuse assignment'),
+#    ('Fellow_accepts_or_refuse_assignment', 'Fellow must accept or refuse assignment'),
     ('EIC_runs_refereeing_round', 'Editor-in-charge to run refereeing round (inviting referees)'),
     ('EIC_closes_refereeing_round', 'Editor-in-charge to close refereeing round'),
     ('EIC_invites_author_response', 'Editor-in-charge invites authors to complete their replies'),
@@ -118,7 +118,7 @@ class Submission(models.Model):
 
 
     def header_as_li_for_Fellows (self):
-        # for submissions queue
+        # for submissions pool
         header = '<li><div class="flex-container">'
         header += '<div class="flex-whitebox0"><p><a href="/submission/{{ id }}" class="pubtitleli">{{ title }}</a></p>'
         header += ('<p>by {{ author_list }}</p><p> (submitted {{ submission_date }} to {{ to_journal }})'
@@ -178,6 +178,7 @@ class EditorialAssignment(models.Model):
     submission = models.ForeignKey(Submission)
     to = models.ForeignKey(Contributor)
     accepted = models.NullBooleanField(choices=ASSIGNMENT_NULLBOOL, default=None)
+    deprecated = models.BooleanField(default=False) # becomes True if another Fellow becomes Editor-in-charge
     completed = models.BooleanField(default=False)
     refusal_reason = models.CharField(max_length=3, choices=ASSIGNMENT_REFUSAL_REASONS, blank=True, null=True)
     date_created = models.DateTimeField(default=timezone.now)
@@ -186,7 +187,7 @@ class EditorialAssignment(models.Model):
     def __str__(self):
         return (self.to.user.first_name + ' ' + self.to.user.last_name + ' to become EIC of ' + 
                 self.submission.title[:30] + ' by ' + self.submission.author_list[:30] +
-                ', assigned on ' + self.date_created.strftime('%Y-%m-%d'))
+                ', requested on ' + self.date_created.strftime('%Y-%m-%d'))
     
     def header_as_li(self):
         header = '<li><div class="flex-container">'
@@ -206,7 +207,7 @@ class EditorialAssignment(models.Model):
         if self.refusal_reason == 'NIE' or self.refusal_reason == 'DNP':
             output += ' style="color: red"'
         output += ('>Fellow {{ first_name }} {{ last_name }}, '
-                  'assigned {{ date_created }}, declined {{ date_answered }}, '
+                  'requested {{ date_created }}, declined {{ date_answered }}, '
                    'reason: {{ reason }}</li>')
         template = Template(output)
         context = Context({'first_name': self.to.user.first_name,
diff --git a/submissions/templates/submissions/accept_or_decline_assignments.html b/submissions/templates/submissions/accept_or_decline_assignments.html
index 066c4376b269793f0ed11494b22d48e0e94ebe4c..28a662ce8a9d8db94af972ca67ca01115c329cda 100644
--- a/submissions/templates/submissions/accept_or_decline_assignments.html
+++ b/submissions/templates/submissions/accept_or_decline_assignments.html
@@ -26,8 +26,11 @@ $(document).ready(function(){
   {% if not assignment_to_consider %}
   <h1>There are no Assignments for you to consider.</h1>
 
-  {% else %}
+  {% elif errormessage %}
+  <h1></h1>
+  <p>{{ errormessage }}</p>
 
+  {% else %}
   <div class="flex-greybox">
     <h1>SciPost Submission: can you act as Editor-in-charge? (see below to accept/decline):</h1>
   </div>
diff --git a/submissions/templates/submissions/queue.html b/submissions/templates/submissions/pool.html
similarity index 63%
rename from submissions/templates/submissions/queue.html
rename to submissions/templates/submissions/pool.html
index 9b135162018b1166eed99bdb4eb07ef60c94b608..5e75f93f6058e0ec54d59ce674086fad852f4e8b 100644
--- a/submissions/templates/submissions/queue.html
+++ b/submissions/templates/submissions/pool.html
@@ -1,6 +1,6 @@
 {% extends 'scipost/base.html' %}
 
-{% block pagetitle %}: Submissions Queue{% endblock pagetitle %}
+{% block pagetitle %}: Submissions Pool{% endblock pagetitle %}
 
 {% block bodysup %}
 
@@ -8,12 +8,12 @@
 <section>
   <div class="flex-container">
     <div class="flex-greybox320">
-      <h1>SciPost Submissions Queue</h1>
+      <h1>SciPost Submissions Pool</h1>
     </div>
   </div>
 
   <ul>
-    {% for sub in submissions_in_queue %}
+    {% for sub in submissions_in_pool %}
     {{ sub.header_as_li_for_Fellows }}
     {% endfor %}
   </ul>
diff --git a/submissions/templates/submissions/submit_manuscript.html b/submissions/templates/submissions/submit_manuscript.html
index 9ff54998f78ba8f12f89969f6b778836bd8ccb57..2684506eb4e577bdbeb0a35b3099023080a0ab74 100644
--- a/submissions/templates/submissions/submit_manuscript.html
+++ b/submissions/templates/submissions/submit_manuscript.html
@@ -16,7 +16,7 @@
     and the <a href="{% url 'journals:journals_terms_and_conditions' %}#author_obligations">author obligations</a>.</p>
   <p>Please prepare your manuscript according to the <a href="{% url 'submissions:author_guidelines' %}">author guidelines</a>.</p>
   
-  {% if True %} <!-- Temporary deactivate submissions -->
+  {% if False %} <!-- Temporary deactivate submissions -->
 
   {% if perms.scipost.can_submit_manuscript %}
 
diff --git a/submissions/urls.py b/submissions/urls.py
index f15081962124226d94e1a44e475af57fd104b942..65bc8cb0d7d71ae587b0732e748de84eae5bc947 100644
--- a/submissions/urls.py
+++ b/submissions/urls.py
@@ -14,7 +14,7 @@ urlpatterns = [
     url(r'^prefill_using_identifier$', views.prefill_using_identifier, name='prefill_using_identifier'),
     url(r'^submit_manuscript$', views.submit_manuscript, name='submit_manuscript'),
     url(r'^submit_manuscript_ack$', TemplateView.as_view(template_name='submissions/submit_manuscript_ack.html'), name='submit_manuscript_ack'),
-    url(r'^queue$', views.queue, name='queue'),
+    url(r'^pool$', views.pool, name='pool'),
     # Assignment of Editor-in-charge
     url(r'^assign_submissions$', views.assign_submissions, name='assign_submissions'),
     url(r'^assign_submission_ack/(?P<submission_id>[0-9]+)$', views.assign_submission_ack, name='assign_submission_ack'),
diff --git a/submissions/views.py b/submissions/views.py
index fc3bcebf5410054eb43bf9cfdf4860eccc44c4e7..c8ad1f9ac4458295a71f8e68cd0d84d5c5e78be7 100644
--- a/submissions/views.py
+++ b/submissions/views.py
@@ -126,7 +126,7 @@ def submissions(request):
                 title__icontains=form.cleaned_data['title_keyword'],
                 author_list__icontains=form.cleaned_data['author'],
                 abstract__icontains=form.cleaned_data['abstract_keyword'],
-                ).exclude(status__in=['unassigned', 'assigned', 'assignment_failed']).order_by('-submission_date')
+                ).exclude(status__in=['unassigned', 'assignment_failed']).order_by('-submission_date')
         else:
             submission_search_list = [] 
            
@@ -136,7 +136,7 @@ def submissions(request):
 
     submission_recent_list = Submission.objects.filter(
         latest_activity__gte=timezone.now() + datetime.timedelta(days=-7)
-    ).exclude(status__in=['unassigned', 'assigned', 'assignment_failed']).order_by('-submission_date')
+    ).exclude(status__in=['unassigned', 'assignment_failed']).order_by('-submission_date')
     context = {'form': form, 'submission_search_list': submission_search_list, 
                'submission_recent_list': submission_recent_list }
     return render(request, 'submissions/submissions.html', context)
@@ -150,7 +150,7 @@ def browse(request, discipline, nrweeksback):
                 title__icontains=form.cleaned_data['title_keyword'],
                 author_list__icontains=form.cleaned_data['author'],
                 abstract__icontains=form.cleaned_data['abstract_keyword'],
-                ).exclude(status__in=['unassigned', 'assigned', 'assignment_failed']).order_by('-submission_date')
+                ).exclude(status__in=['unassigned', 'assignment_failed']).order_by('-submission_date')
         else:
             submission_search_list = []
         context = {'form': form, 'submission_search_list': submission_search_list }
@@ -160,7 +160,7 @@ def browse(request, discipline, nrweeksback):
     submission_browse_list = Submission.objects.filter(
         discipline=discipline, 
         latest_activity__gte=timezone.now() + datetime.timedelta(weeks=-int(nrweeksback))
-        ).exclude(status__in=['unassigned', 'assigned', 'assignment_failed']).order_by('-submission_date')
+        ).exclude(status__in=['unassigned', 'assignment_failed']).order_by('-submission_date')
     context = {'form': form, 'discipline': discipline, 'nrweeksback': nrweeksback, 
                'submission_browse_list': submission_browse_list }
     return render(request, 'submissions/submissions.html', context)
@@ -214,17 +214,17 @@ def submission_detail(request, submission_id):
 ######################
 
 @permission_required('scipost.can_take_charge_of_submissions', raise_exception=True)
-def queue(request):
+def pool(request):
     """
     The Submissions queue contains all submissions which are undergoing
     the editorial process, from assignment acceptance (Editor-in-charge appointed)
     to publication acceptance or rejection.
     All members of the Editorial College have access.
     """
-    submissions_in_queue=Submission.objects.all().exclude(status__in=['decided'])
+    submissions_in_pool=Submission.objects.all().exclude(status__in=['decided'])
 
-    context = {'submissions_in_queue': submissions_in_queue}
-    return render(request, 'submissions/queue.html', context)
+    context = {'submissions_in_pool': submissions_in_pool}
+    return render(request, 'submissions/pool.html', context)
 
     
 @permission_required('scipost.can_assign_submissions', raise_exception=True)
@@ -251,20 +251,17 @@ def assign_submission_ack(request, submission_id):
     if request.method == 'POST':
         form = AssignSubmissionForm(request.POST, discipline=submission.discipline)
         if form.is_valid():
-            editor_in_charge = form.cleaned_data['editor_in_charge']
+            suggested_editor_in_charge = form.cleaned_data['editor_in_charge']
             ed_assignment = EditorialAssignment(submission=submission,
-                                                to=editor_in_charge,
+                                                to=suggested_editor_in_charge,
                                                 date_created=timezone.now())
             ed_assignment.save()
-            submission.status = 'assigned'
-            submission.latest_activity = timezone.now()
-            submission.save()
             # Email Fellow
             email_text = ('Dear ' + title_dict[ed_assignment.to.title] + ' ' +
                           ed_assignment.to.user.last_name +
                           ', \n\nWe have received a Submission to SciPost ' +
                           'for which we would like you to consider becoming Editor-in-charge:\n\n' +
-                          submission.title + ' by ' + submission.author_list +
+                          submission.title + ' by ' + submission.author_list + '.' +
                           '\n\nPlease visit https://scipost.org/submissions/accept_or_decline_assignments \n' +
                           'in order to accept or decline. Many thanks in advance for your consideration.  ' +
                           '\n\nThe SciPost Team.')
@@ -284,8 +281,20 @@ def assign_submission_ack(request, submission_id):
 def accept_or_decline_assignments(request):
     contributor = Contributor.objects.get(user=request.user)
     assignment = EditorialAssignment.objects.filter(to=contributor, accepted=None).first()
+    errormessage = None
+    if assignment.submission.statue == 'assignment_failed':
+        errormessage = 'This Submission has failed pre-screening and has been rejected.'
+        assignment.deprecated = True
+        assignment.save()
+    elif assignment.submission.status != 'unassigned': # already assigned, or deprecated
+        errormessage = (title_dict[assignment.submission.editor_in_charge.title] +
+                        assignment.submission.editor_in_charge.user.last_name + 
+                        ' has already agreed to be Editor-in-charge of this Submission.')
+        assignment.deprecated = True
+        assignment.save()
     form = ConsiderAssignmentForm()
-    context = {'assignment_to_consider': assignment, 'form': form}
+    context = {'assignment_to_consider': assignment, 'form': form,
+               'errormessage': errormessage}
     return render(request, 'submissions/accept_or_decline_assignments.html', context)
 
 
@@ -297,15 +306,15 @@ def accept_or_decline_assignment_ack(request, assignment_id):
         form = ConsiderAssignmentForm(request.POST)
         if form.is_valid():
             assignment.date_answered = timezone.now()
-            deadline = timezone.now() + datetime.timedelta(days=28) # for papers
-            if assignment.submission.submitted_to_journal == 'SciPost Physics Lecture Notes':
-                deadline += datetime.timedelta(days=28)
             if form.cleaned_data['accept'] == 'True':
                 assignment.accepted = True
                 assignment.to = contributor
                 assignment.submission.status = 'EICassigned'
                 assignment.submission.editor_in_charge = contributor
                 assignment.submission.open_for_reporting = True
+                deadline = timezone.now() + datetime.timedelta(days=28) # for papers
+                if assignment.submission.submitted_to_journal == 'SciPost Physics Lecture Notes':
+                    deadline += datetime.timedelta(days=28)
                 assignment.submission.reporting_deadline = deadline
                 assignment.submission.open_for_commenting = True
             else:
@@ -322,7 +331,7 @@ def accept_or_decline_assignment_ack(request, assignment_id):
 @permission_required('scipost.can_take_charge_of_submissions', raise_exception=True)
 def volunteer_as_EIC(request, submission_id):
     """ 
     Called when a Fellow volunteers while perusing the submissions queue.
     This is an adapted version of the accept_or_decline_assignment_ack method.
     """
     submission = get_object_or_404(Submission, pk=submission_id)
@@ -342,6 +351,12 @@ def volunteer_as_EIC(request, submission_id):
     submission.open_for_commenting = True
     assignment.save()
     submission.save()
+    # Deactivate the other assignments
+    assignments_to_deactivate = EditorialAssignment.objects.filter(
+        submission=submission, accepted=None)
+    for a_to_deact in assignments_to_deactivate:
+        a_to_deact.deprecated = True
+        a_to_deact.save()
     context = {'assignment': assignment}
     return render(request, 'submissions/accept_or_decline_assignment_ack.html', context)
@@ -214,17 +214,17 @@ def submission_detail(request, submission_id):
     """
-    The Submissions queue contains all submissions which are undergoing
-    the editorial process, from assignment acceptance (Editor-in-charge appointed)
+    The Submissions pool contains all submissions which are undergoing
+    the editorial process, from submission
     to publication acceptance or rejection.
     All members of the Editorial College have access.
@@ -322,7 +331,7 @@ def accept_or_decline_assignment_ack(request, assignment_id):
 def volunteer_as_EIC(request, submission_id):
     """ 
-    Called when a Fellow volunteers while perusing the submissions queue.
+    Called when a Fellow volunteers while perusing the submissions pool.
     This is an adapted version of the accept_or_decline_assignment_ack method.
     """